==> simulagora-0.1.0.tar.gz: simulagora-0.1.0/__pkginfo__.py <==
# pylint: disable=W0622
# copyright 2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of simulagora.
#
# logilab-mtconverter is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# logilab-mtconverter is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.

"""simulagora-client application packaging information"""

import os.path as osp

modname = 'simulagora'
distname = 'simulagora'

numversion = (0, 1, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
author = 'LOGILAB S.A. (Paris, FRANCE)'
author_email = 'contact@logilab.fr'
description = 'A python library to use Simulagora programatically'
web = 'http://www.cubicweb.org/project/simulagora-client'

__depends__ =  {'cwclient': '>= 0.2.0'}
__recommends__ = {}
scripts = (osp.join('bin', 'simulagora'),)

classifiers = [
    'Environment :: Console',
    'Intended Audience :: Science/Research',
    'Programming Language :: Python',
    'Topic :: Scientific/Engineering',
    ]

==> simulagora-0.1.1.tar.gz: simulagora-0.1.1/__pkginfo__.py <==
# pylint: disable=W0622
# copyright 2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of simulagora.
#
# logilab-mtconverter is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# logilab-mtconverter is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.

"""simulagora-client application packaging information"""

import os.path as osp

modname = 'simulagora'
distname = 'simulagora'

numversion = (0, 1, 1)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
author = 'LOGILAB S.A. (Paris, FRANCE)'
author_email = 'contact@logilab.fr'
description = 'A python library to use Simulagora programatically'
web = 'http://www.cubicweb.org/project/simulagora-client'

__depends__ =  {'cwclientlib': '>= 0.2.0'}
__recommends__ = {}
scripts = (osp.join('bin', 'simulagora'),)

classifiers = [
    'Environment :: Console',
    'Intended Audience :: Science/Research',
    'Programming Language :: Python',
    'Topic :: Scientific/Engineering',
    ]
